Page 61 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 61

Home

    Blessed is the nation whose God is the Lord,...
    Psalms 33:12

    The most amazing thing about the American Republic
    is that it came into existence. Born into a hostile world,

    brought to birth by a divided band of colonies, facing one
    of the most powerful nations on earth determined to
    destroy it, how could it survive? The answer is, the
    American Republic almost did not survive.

    The Declaration of Independence, the defeat of the
    British, the writing and ratification of the Constitution,
    were all events not likely to have happened without the
    aid of Divine Providence. This is attested to by the
    actions and expressions of those involved in these

    events.

    The painting of George Washington kneeling in the
    snow and praying at Valley Forge did not come about as
    a result of some artist s fancy, but because of the witness

    of Isaac Potts who, while walking through the woods,
    accidentally came across Washington praying in a grove
    of oaks. General Knox, Who was with Washington | at

    Valley Forge, stated that Washington frequently used the
    grove for prayer.

    56

    Chapter 7

    The American Republic